@@ -5,7 +5,7 @@ with open("README.md", "r") as fh:
 
 setuptools.setup(
     name="hscan",
-    version="2.3.5",
+    version="2.5.1",
     author="jyanghe",
     author_email="jyanghe1023@gmail.com",
     description="A python framework",
@@ -20,7 +20,7 @@ setuptools.setup(
     ],
     python_requires='>=3.8.0',
     install_requires=[
-        'httpx[http2]==0.22.0',
+        'httpx[http2]==0.24.1',
         'aiofiles==0.7.0',
         'aio-pika==6.8.0',
         'beautifulsoup4==4.9.3',
@@ -30,6 +30,8 @@ setuptools.setup(
         'pymongo==3.12.0',
         'chardet==4.0.0',
         'asyncpg==0.26.0',
-        'aiokafka==0.8.0'
+        'aiokafka==0.8.0',
+        'oss2==2.15.0',
+        'aiomysql==0.1.1'
     ]
 )
