@@ -11,6 +11,9 @@ class Config:
         config.read(cfg_file_path, encoding="utf-8")
         return config
 
+    def postgres(self):
+        return dict(self.config.items('postgres'))
+
     def mongo(self):
         return dict(self.config.items('mongo'))
 
@@ -26,6 +29,9 @@ class Config:
     def oss(self):
         return dict(self.config.items('oss'))
 
+    def kafka(self):
+        return dict(self.config.items('kafka'))
+
     def other(self):
         return dict(self.config.items('other'))
 
