@@ -2,3 +2,5 @@ from scan.database.rabbitmq import RabbitMQ
 from scan.database.redis import Redis
 from scan.database.mongodb import MongoDB
 from scan.database.oss import OSS
+from scan.database.pg import Postgresql
+from scan.database.kafka import Kafka
\ No newline at end of file
