@@ -79,16 +79,27 @@ class RabbitMQ:
         except Exception as e:
             logger.error(f'consume process error: {e}')
 
-    async def publish(self, data, routing_key, priority=None):
+    async def publish(self, data, routing_key, priority=None, channel=None):
         """
         :param priority: 消息优先级
         :param data: 要发送的数据
         :param routing_key: 队列名
+        :param channel: 通道
         :return:
         """
         try:
-            channel = await self.get_channel()
-            async with channel:
+            if not channel:
+                channel = await self.get_channel()
+                async with channel:
+                    data = json.dumps(data)
+                    for _ in range(3):
+                        try:
+                            await channel.default_exchange.publish(aio_pika.Message(body=data.encode(), priority=priority),
+                                                                   routing_key=routing_key)
+                            return True
+                        except Exception as e:
+                            logger.error(f'publish error: {e}')
+            else:
                 data = json.dumps(data)
                 for _ in range(3):
                     try:
